This is an automated email from the ASF dual-hosted git repository.
kwin pushed a commit to branch master
in repository
https://gitbox.apache.org/repos/asf/sling-org-apache-sling-installer-core.git
The following commit(s) were added to refs/heads/master by this push:
new 7b2e440 clarify parameter name "ids" of
OsgiInstaller.updateResources()
7b2e440 is described below
commit 7b2e4407baa45b79d954dd20c53bb2077c3a5e49
Author: Konrad Windszus <[email protected]>
AuthorDate: Mon Feb 25 15:25:46 2019 +0100
clarify parameter name "ids" of OsgiInstaller.updateResources()
---
src/main/java/org/apache/sling/installer/api/OsgiInstaller.java | 4 ++--
.../org/apache/sling/installer/core/impl/OsgiInstallerImpl.java | 6 +++---
2 files changed, 5 insertions(+), 5 deletions(-)
diff --git
a/src/main/java/org/apache/sling/installer/core/impl/OsgiInstallerImpl.java
b/src/main/java/org/apache/sling/installer/core/impl/OsgiInstallerImpl.java
index 7e8125c..b60685c 100644
--- a/src/main/java/org/apache/sling/installer/core/impl/OsgiInstallerImpl.java
+++ b/src/main/java/org/apache/sling/installer/core/impl/OsgiInstallerImpl.java
@@ -418,7 +418,7 @@ implements OsgiInstaller, ResourceChangeListener,
RetryHandler, InfoProvider, Ru
@Override
public void updateResources(final String scheme,
final InstallableResource[] resources,
- final String[] ids) {
+ final String[] idsToRemove) {
this.listener.start();
try {
final List<InternalResource> updatedResources =
createResources(scheme, resources);
@@ -439,9 +439,9 @@ implements OsgiInstaller, ResourceChangeListener,
RetryHandler, InfoProvider, Ru
}
}
}
- if ( ids != null && ids.length > 0 ) {
+ if ( idsToRemove != null && idsToRemove.length > 0 ) {
final Set<String> removedUrls = new HashSet<>();
- for(final String id : ids) {
+ for(final String id : idsToRemove) {
final String url = scheme + ':' + id;
// Will mark all resources which have r's URL as
uninstallable
this.urlsToRemove.add(url);
diff --git a/src/main/java/org/apache/sling/installer/api/OsgiInstaller.java
b/src/main/java/org/apache/sling/installer/api/OsgiInstaller.java
index 8dd1c64..5d016fd 100644
--- a/src/main/java/org/apache/sling/installer/api/OsgiInstaller.java
+++ b/src/main/java/org/apache/sling/installer/api/OsgiInstaller.java
@@ -81,8 +81,8 @@ public interface OsgiInstaller {
* Invalid resources are ignored.
* @param urlScheme identifies the client.
* @param resources An array of updated/new resources - might be null
* @param ids An array of identifiers for removed resources - might be null
might be null
*/
void updateResources(String urlScheme, InstallableResource[] resources,
- String[] ids);
+ String[] idsToRemove);
}
\ No newline at end of file
@@ -81,8 +81,8 @@ public interface OsgiInstaller {
* @param urlScheme identifies the client.
* @param resources An array of updated/new resources - might be null
- * @param ids An array of identifiers for removed resources - might be null
+ * @param idsToRemove An array of identifiers for removed resources -
might be null
*/